window.Gleam.initSearch([{"doc":"okay","title":"okay","content":"# okay\n\n[![Package Version](https://img.shields.io/hexpm/v/okay)](https://hex.pm/packages/okay)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/okay/)\n\n```sh\ngleam add okay@1\n```\n```gleam\nimport okay\n\npub type User {\n  User(id: Int, name: String, age: Int)\n}\n\npub fn main() {\n  let user = User(id: 1, name: &quot;John&quot;, age: 20)\n\n  let assert Ok(_) = okay.new()\n  |&gt; okay.field(&quot;age&quot;, okay.is_gt(user.age, 18))\n  |&gt; okay.field(&quot;name&quot;, okay.is_longer(user.name, 1))\n  |&gt; okay.run()\n\n  let assert Error(validator) =\n    okay.new()\n    |&gt; okay.field(&quot;age&quot;, okay.is_gt(user.age, 30))\n    |&gt; okay.field(&quot;name&quot;, okay.is_longer(user.name, 5))\n    |&gt; okay.run()\n\n  let assert [first, second] = validator.errors\n  io.debug(first) // ValidationError(&quot;age&quot;, IsGreater(value: 20, expected: 30))\n  io.debug(second) // ValidationError(&quot;name&quot;, IsLonger(value: &quot;John&quot;, actual: 4, expected: 5))\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/okay&gt;.\n\n## Development\n\n```sh\ngleam run   # Run the project\ngleam test  # Run the tests\n```\n","url":"index.html"},{"doc":"okay","title":"Error","content":"pub type Error {\n  IsGreater(value: Int, expected: Int)\n  IsGreaterOrEqual(value: Int, expected: Int)\n  IsLonger(value: String, actual: Int, expected: Int)\n  IsLesser(value: Int, expected: Int)\n  IsLesserOrEqual(value: Int, expected: Int)\n  IsEqual(value: String, expected: String)\n  IsIncludedIn(value: String, expected: String)\n  IsBool(value: Bool, expected: Bool)\n  IsSome\n  IsNone(value: String)\n}\n The different types of error messages, these can be used to later build human readable messages like:\n `The string &quot;John&quot; expected to be longer then 10 characters but was actually 4`\nIsGreater(value: Int, expected: Int)\n\n\nIsGreaterOrEqual(value: Int, expected: Int)\n\n\nIsLonger(value: String, actual: Int, expected: Int)\n\n\nIsLesser(value: Int, expected: Int)\n\n\nIsLesserOrEqual(value: Int, expected: Int)\n\n\nIsEqual(value: String, expected: String)\n\n\nIsIncludedIn(value: String, expected: String)\n\n\nIsBool(value: Bool, expected: Bool)\n\n\nIsSome\n\n\nIsNone(value: String)\n\n\nSynonyms:\nokay.Error\nokay Error","url":"okay.html#Error"},{"doc":"okay","title":"Okay","content":"pub type Okay {\n  Okay(errors: List(ValidationError))\n}\n The `Okay` type is used to store the list of validation errors\nOkay(errors: List(ValidationError))\n\n\nSynonyms:\nokay.Okay\nokay Okay","url":"okay.html#Okay"},{"doc":"okay","title":"ValidationError","content":"pub type ValidationError {\n  ValidationError(field: String, error: Error)\n}\n The `ValidationError` type consists of the field name and the error\nValidationError(field: String, error: Error)\n\n\nSynonyms:\nokay.ValidationError\nokay ValidationError","url":"okay.html#ValidationError"},{"doc":"okay","title":"field","content":"pub fn field(\n  okay: Okay,\n  field: String,\n  result: Result(Nil, Error),\n) -&gt; Okay\n Based on the validation function result, it&#39;ll append the Error to the `Okay.errors` list\nSynonyms:\nokay.field\nokay field","url":"okay.html#field"},{"doc":"okay","title":"is_equal","content":"pub fn is_equal(value: a, compare: a) -&gt; Result(Nil, Error)\n Checks if two values are equal to each other\n # Examples\n \n let assert Ok(_) = okay.is_equal(&quot;hi&quot;, &quot;hi&quot;)\n let assert Error(_error) = okay.is_equal(1, 2)\n \n\nSynonyms:\nokay.is_equal\nokay is_equal","url":"okay.html#is_equal"},{"doc":"okay","title":"is_false","content":"pub fn is_false(value: Bool) -&gt; Result(Nil, Error)\n Checks if bool is False\n # Examples\n \n let assert Ok(_) = okay.is_false(False)\n let assert Error(_error) = okay.is_false(True)\n \n\nSynonyms:\nokay.is_false\nokay is_false","url":"okay.html#is_false"},{"doc":"okay","title":"is_gt","content":"pub fn is_gt(value: Int, compare: Int) -&gt; Result(Nil, Error)\n Checks if one Int is greater than another\n # Examples\n \n let assert Ok(_) = okay.is_gt(10, 1)\n let assert Error(_error) = okay.is_gt(1, 10)\n \n\nSynonyms:\nokay.is_gt\nokay is_gt","url":"okay.html#is_gt"},{"doc":"okay","title":"is_gte","content":"pub fn is_gte(value: Int, compare: Int) -&gt; Result(Nil, Error)\n Checks if one Int is greater than or equal to another\n # Examples\n \n let assert Ok(_) = okay.is_gte(10, 10)\n let assert Error(_error) = okay.is_gte(9, 10)\n \n\nSynonyms:\nokay.is_gte\nokay is_gte","url":"okay.html#is_gte"},{"doc":"okay","title":"is_included_in","content":"pub fn is_included_in(\n  value: a,\n  whitelist: List(a),\n) -&gt; Result(Nil, Error)\n Checks if values is included in the list\n # Examples\n \n let assert Ok(_) = okay.is_included_in(1, [1, 2])\n let assert Error(_error) = okay.is_included_in(3, [1, 2])\n \n\nSynonyms:\nokay.is_included_in\nokay is_included_in","url":"okay.html#is_included_in"},{"doc":"okay","title":"is_longer","content":"pub fn is_longer(\n  value: String,\n  length: Int,\n) -&gt; Result(Nil, Error)\n Checks if string is longer than X amount\n # Examples\n \n let assert Ok(_) = okay.is_longer(&quot;hello&quot;, 1)\n let assert Error(_error) = okay.is_longer(&quot;A&quot;, 2)\n \n\nSynonyms:\nokay.is_longer\nokay is_longer","url":"okay.html#is_longer"},{"doc":"okay","title":"is_lt","content":"pub fn is_lt(value: Int, compare: Int) -&gt; Result(Nil, Error)\n Checks if one Int is less than another\n # Examples\n \n let assert Ok(_) = okay.is_lt(1, 2)\n let assert Error(_error) = okay.is_lt(5, 1)\n \n\nSynonyms:\nokay.is_lt\nokay is_lt","url":"okay.html#is_lt"},{"doc":"okay","title":"is_lte","content":"pub fn is_lte(value: Int, compare: Int) -&gt; Result(Nil, Error)\n Checks if one Int is less than or equal to another\n # Examples\n \n let assert Ok(_) = okay.is_lte(8, 8)\n let assert Error(_error) = okay.is_lte(9, 8)\n \n\nSynonyms:\nokay.is_lte\nokay is_lte","url":"okay.html#is_lte"},{"doc":"okay","title":"is_none","content":"pub fn is_none(value: Option(a)) -&gt; Result(Nil, Error)\n Checks if Option is None\n # Examples\n \n let assert Ok(_) = okay.is_none(option.None)\n let assert Error(_error) = okay.is_noe(option.Some(1))\n \n\nSynonyms:\nokay.is_none\nokay is_none","url":"okay.html#is_none"},{"doc":"okay","title":"is_some","content":"pub fn is_some(value: Option(a)) -&gt; Result(Nil, Error)\n Checks if Option is Some\n # Examples\n \n let assert Ok(_) = okay.is_some(option.Some(1))\n let assert Error(_error) = okay.is_some(option.None)\n \n\nSynonyms:\nokay.is_some\nokay is_some","url":"okay.html#is_some"},{"doc":"okay","title":"is_true","content":"pub fn is_true(value: Bool) -&gt; Result(Nil, Error)\n Checks if bool is True\n # Examples\n \n let assert Ok(_) = okay.is_true(True)\n let assert Error(_error) = okay.is_true(False)\n \n\nSynonyms:\nokay.is_true\nokay is_true","url":"okay.html#is_true"},{"doc":"okay","title":"new","content":"pub fn new() -&gt; Okay\n Initializes a `Okay` record with an empty list of errors\nSynonyms:\nokay.new\nokay new","url":"okay.html#new"},{"doc":"okay","title":"run","content":"pub fn run(okay: Okay) -&gt; Result(Nil, Okay)\n Checks if the `Okay` record contains any errors and responds with a Result\nSynonyms:\nokay.run\nokay run","url":"okay.html#run"},{"doc":"okay","title":"okay","content":"","url":"okay.html"}]);